@@ -78,8 +78,9 @@ if {[get_gnats_config] == "-1"} {
     exit
 }
 
-#TTD remove me after testing
-#set TkGnats(ReleaseBased) 1
+# Remove "pending" from the Category list
+set idx [lsearch -exact $TkGnats(CategoryList) "pending"]
+set TkGnats(CategoryList) [lreplace $TkGnats(CategoryList) $idx $idx]
 
 proc headingMsg {a} {
     .action.msg configure -text $a
@@ -90,104 +91,94 @@ proc headingMsg {a} {
 # Before assembly some of the widgets are checked for validity.
 
 proc send_report {} {
-    global TkGnats Tksendpr frm
+    global TkGnats Tksendpr frm current_multi_text Class State Priority Severity Confidential Category Submitter-Id Responsible
     
     flush_singletext $Tksendpr(singletextflds)
     flush_multitext
     
     # check all the fields first...
 
-    foreach v {
-	Confidential Severity Priority Class Category Submitter
-    } {
-	global $v
-	switch -exact -- [set $v] "" {
-	    Msg "An option from '$v' must be selected."
-	    return -1
+    # Check for blank mandatory fields.
+    foreach f [concat $Tksendpr(radioflds) $Tksendpr(listboxflds) $Tksendpr(singletextflds) $Tksendpr(multitextflds)] {
+        if {[check_suppressed_field $f]} {
+            continue
+        }
+	if {![check_mandatory_field $f]} {
+	    continue
 	}
+	if {[info exists frm($f)]} {
+	    # singletext and multitext
+	    set val $frm($f)
+	} {
+	    # radiobutton and listbox fields
+	    set val [set $f]
+	}
+        set val [string trim $val " \n\t\f!:~-#_?"]
+        if {$val == ""} {
+            Msg "You must supply a value for '[get_field_alias $f]'."
+            return -1
+        }
     }
 
-    if {[lsearch -exact $TkGnats(CategoryList) $Category] < 0} {
-        Msg "You have specified an invalid Category!"
-        return -1
-    }
-        
-    if {[lsearch -exact $TkGnats(SubmitterList) $Submitter] < 0} {
-        Msg "You have specified an invalid Submitter-Id!"
-        return -1
-    }
-     
-    foreach t {
-	Originator Synopsis Reply-To Description How-To-Repeat 
-    } {
-	if {$t == "Description" || $t == "How-To-Repeat"} {
-            set x $frm(>$t)
-        } {
-            set x [textget $t]
-        }
-	set x [string trim $x " \n\t\f!:~-#_?"]
-	# If a change request, don't demand a How-To-Repeat
-	if {$t == "How-To-Repeat"} {
-	    global Class
-	    if {$Class == "change-request"} {
-		continue
+    # Check listbox fields
+    foreach {field list} {Category Category Submitter-Id Submitter Responsible Responsible} {
+	if {![check_suppressed_field $field]} {
+	    if {[set $field] != "" && [lsearch -exact $TkGnats(${list}List) [set $field]] < 0} {
+		Msg "You have specified an invalid [get_field_alias $field]: [set $field]"
+		return -1
 	    }
 	}
-	switch -exact --  $x "" {
-	    Msg "Field '$t' is not complete.\n" "Type in something descriptive."
-	    return -1
-	}
     }
 
-    set flist {
-	Originator Release Synopsis Reply-To
+    foreach f $Tksendpr(singletextflds) {
+        if {[string first "|" $frm($f)] >= 0} {
+            Msg " '|' is an illegal character for the '[get_field_alias $f]' field!"
+            return -1
+        }
     }
 
-    if {$TkGnats(ReleaseBased)} {
-	lappend flist Keywords $TkGnats(Quarter) Date-Required
+    if {$TkGnats(ReleaseBased) && ![check_suppressed_field Date-Required]} {
+        if {[check_date_invalid $frm(Date-Required) "Invalid [get_field_alias Date-Required]:"]} {
+            return -1
+        }
     }
-    
-    foreach t $flist {
-	if {[string first "|" [textget $t]] != -1} {
-	    Msg " '|' is an illegal character for the '$t' field!"
-	    return -1
-	}
-    }
-
+        
     # ok, now send off the report
 
-    set mailtxt ""
+    set    mailtxt ""
     append mailtxt "From: $TkGnats(EmailAddr)\n"
-    append mailtxt "Reply-To: [string trim [textget Reply-To]]\n"
+    append mailtxt "Reply-To: $TkGnats(EmailAddr)\n"
     append mailtxt "To: $TkGnats(GNATS_ADDR)\n"
-    append mailtxt "Subject: [string trim [textget Synopsis]]\n"
+    append mailtxt "Subject: [string trim $frm(Synopsis)]\n"
     append mailtxt "X-send-pr-version: $Tksendpr(version)\n"
+    append mailtxt "X-GNATS-Notify: [add_email_domainname [string trim $frm(X-GNATS-Notify)]]\n"
     append mailtxt "\n"
-    #### End of std mail headers
-
-    append mailtxt ">Submitter-Id: $Submitter\n"
-    foreach v {
-	Confidential Severity Priority Category Class
-    } {
-	append mailtxt ">${v}:	[set $v]\n"
-    }
-
-    set flist {
-	Synopsis Originator Release 
+    #### End of standard mail headers
+    
+    foreach f [concat $Tksendpr(radioflds) $Tksendpr(listboxflds)] {
+        if {![check_suppressed_field $f]} {
+	    append mailtxt ">${f}:	[set $f]\n"
+	} elseif {[info exists TkGnats(CreateDefault$f)]} {
+	    append mailtxt ">${f}:	$TkGnats(CreateDefault$f)\n"
+        }
     }
     
-    if {$TkGnats(ReleaseBased)} {
-	lappend flist Keywords $TkGnats(Quarter) Date-Required
+    foreach f $Tksendpr(singletextflds) {
+        if {$f != "X-GNATS-Notify"} {
+            if {![check_suppressed_field $f]} {
+                append mailtxt ">${f}: $frm($f)\n"
+            } elseif {[info exists TkGnats(CreateDefault$f)]} {
+                append mailtxt ">${f}: $TkGnats(CreateDefault$f)\n"
+            }
+        }
     }
     
-    foreach t $flist {
-	append mailtxt ">${t}: [textget $t]\n"
-    }
-
-    foreach t {
-	Environment Description How-To-Repeat Fix Organization
-    } {
-	append mailtxt ">${t}:\n$frm(>$t)\n"
+    foreach f $Tksendpr(multitextflds) {
+        if {![check_suppressed_field $f]} {
+	    append mailtxt "${f}:\n$frm($f)\n"
+	} elseif {[info exists TkGnats(CreateDefault[string trim $f >])]} {
+	    append mailtxt "${f}:\n$TkGnats(CreateDefault[string trim $f >])\n"
+        }
     }
 
     #
@@ -206,28 +197,22 @@ proc send_report {} {
     # clear out some fields
     #
 
-    set flist {
-	Synopsis
-    }
-
+    set flist {Synopsis}
     if {$TkGnats(ReleaseBased)} {
 	lappend flist Keywords $TkGnats(Quarter) Date-Required
     }
-
-    foreach t $flist {
-	textset $t ""
+    foreach f $flist {
+	textset $f ""
     }
-    
-    foreach t {
-	Environment Description How-To-Repeat Fix Organization
-    } {
-	set frm(>$t) ""
-    }
-    .multiline.text delete 1.0 end
-    switch_txt ">Description" $Tksendpr(multitextflds)
     # Some folks may not want these reset
-    set frm(>Environment)  [env_fld_text]
-    set frm(>Organization) [org_fld_text]
+    #foreach t {Environment Description How-To-Repeat Fix Organization}
+    foreach f {Description How-To-Repeat Fix} {
+	set frm(>$f) ""
+        if {">$f" == $current_multi_text} {
+            .multiline.text delete 1.0 end
+        }
+    }
+    switch_txt $TkGnats(first_multitext) $Tksendpr(multitextflds)
     return 0
 }
 
@@ -243,15 +228,17 @@ proc cancel_report {} {
 }
 
 proc snd_category_listbox {p category_list} {
-    global TkGnats Tksendpr Category Category_wid
+    global TkGnats Tksendpr Category
     set Category ""
 
+    set alias [get_field_alias Category]
     frame  $p.cat -relief groove  -borderwidth 2
     pack   $p.cat -side top -expand true -fill both
-    button $p.cat.msg -anchor w -text "Category: " -width 14 -command "helpMsg Category" \
+    button $p.cat.lab -anchor w -text "${alias}: " -width 14 -command "helpMsg $alias" \
             -relief flat -padx 0 -pady 0 -borderwidth 0
-    set Category_wid [expr 2 + [get_max_strlen $category_list]]
-    set ew [entry  $p.cat.ent -width $Category_wid -insertwidth 1 -insertofftime 400 \
+    frame  $p.cat.msg -relief flat
+    set wid [expr 2 + [get_max_strlen $category_list]]
+    set ew  [entry  $p.cat.msg.ent -width $wid -insertwidth 1 -insertofftime 400 \
             -relief sunken -borderwidth 2 -background $TkGnats(EditFieldBackground) -highlightthickness 2 \
             -textvariable Category]
     lappend Tksendpr(tlist) $ew
@@ -263,35 +250,35 @@ proc snd_category_listbox {p category_list} {
     if {$height > 6 } {
         set height 6
     }
-    scrollbar $p.cat.sb -command "$p.cat.list yview" -borderwidth 2 -relief sunken
-    listbox $p.cat.list -yscroll "$p.cat.sb set" -setgrid 1 -relief sunken -borderwidth 2 \
-            -width $Category_wid -height $height -exportselection false
-    eval   $p.cat.list insert end $category_list
-    pack   $p.cat.msg  -side left  -anchor n
-    pack   $p.cat.ent  -side left  -anchor n
-    pack   $p.cat.sb   -side left  -fill y
-    pack   $p.cat.list -side right -fill both -expand true
-    bind   $p.cat.list <B1-ButtonRelease> "set_snd_category $p.cat.ent %W %y"
-    return $p.cat.list
+    scrollbar $p.cat.msg.sb -command "$p.cat.msg.list yview" -borderwidth 2 -relief sunken
+    listbox   $p.cat.msg.list -yscroll "$p.cat.msg.sb set" -setgrid 1 -relief sunken -borderwidth 2 \
+            -width $wid -height $height -exportselection false
+    eval   $p.cat.msg.list insert end $category_list
+    pack   $p.cat.msg.ent  -side top   -fill x
+    pack   $p.cat.msg.sb   -side right -fill y
+    pack   $p.cat.msg.list -side right -fill both -expand true
+    pack   $p.cat.lab      -side left  -anchor nw -ipady 4
+    pack   $p.cat.msg      -side left  -anchor nw -fill y
+    bind   $p.cat.msg.list <B1-ButtonRelease> "set_snd_category $p.cat.msg.ent %W %y"
+    return $p.cat.msg.list
 }
 
-proc snd_submitter_listbox {p submitters_list} {
-    global TkGnats Tksendpr Submitter Category_wid
-    set Submitter ""
+proc snd_submitter-id_listbox {p submitters_list} {
+    global TkGnats Tksendpr Submitter-Id
+    set Submitter-Id ""
 
+    set alias [get_field_alias Submitter-Id]
     frame  $p.sub -relief groove  -borderwidth 2
     pack   $p.sub -side top -expand true -fill both
-    button $p.sub.msg -anchor w -text "Submitter-Id: " -width 14 -command "helpMsg Submitter-Id" \
+    button $p.sub.lab -anchor w -text "${alias}: " -width 14 -command "helpMsg $alias" \
             -relief flat -padx 0 -pady 0 -borderwidth 0
+    frame  $p.sub.msg -relief flat
     set wid [expr 2 + [get_max_strlen $submitters_list]]
-    if {$Category_wid > $wid} {
-        set wid $Category_wid
-    }
-    set ew [entry  $p.sub.ent -width $wid -insertwidth 1 -insertofftime 400 \
+    set ew  [entry  $p.sub.msg.ent -width $wid -insertwidth 1 -insertofftime 400 \
             -relief sunken -borderwidth 2 -background $TkGnats(EditFieldBackground) -highlightthickness 2 \
-            -textvariable Submitter]
+            -textvariable Submitter-Id]
     lappend Tksendpr(tlist) $ew
-    trace variable Submitter w set_snd_submitter_ew
+    trace variable Submitter-Id w set_snd_submitter-id_ew
     set_focus_style $ew
     bind $ew <BackSpace> { tkEntrySetCursor %W [%W index insert] }
     bind $ew <Control-h> { tkEntrySetCursor %W [%W index insert] }
@@ -299,28 +286,71 @@ proc snd_submitter_listbox {p submitters_list} {
     if {$height > 6 } {
         set height 6
     }
-    scrollbar $p.sub.sb -command "$p.sub.list yview" -borderwidth 2 -relief sunken
-    listbox $p.sub.list -yscroll "$p.sub.sb set" -setgrid 1 -relief sunken -borderwidth 2 \
+    scrollbar $p.sub.msg.sb -command "$p.sub.msg.list yview" -borderwidth 2 -relief sunken
+    listbox   $p.sub.msg.list -yscroll "$p.sub.msg.sb set" -setgrid 1 -relief sunken -borderwidth 2 \
             -width $wid -height $height -exportselection false
-    eval   $p.sub.list insert end $submitters_list
-    pack   $p.sub.msg  -side left  -anchor n
-    pack   $p.sub.ent  -side left  -anchor n
-    pack   $p.sub.sb   -side left  -fill y
-    pack   $p.sub.list -side right -fill both -expand true
-    bind   $p.sub.list <B1-ButtonRelease> "set_snd_submitter $p.sub.ent %W %y"
-    return $p.sub.list
+    eval   $p.sub.msg.list insert end $submitters_list
+    pack   $p.sub.msg.ent  -side top   -fill x
+    pack   $p.sub.msg.sb   -side right -fill y
+    pack   $p.sub.msg.list -side right -fill both -expand true
+    pack   $p.sub.lab      -side left  -anchor nw -ipady 4
+    pack   $p.sub.msg      -side left  -anchor nw -fill y
+    bind   $p.sub.msg.list <B1-ButtonRelease> "set_snd_submitter-id $p.sub.msg.ent %W %y"
+    return $p.sub.msg.list
+}
+  
+proc snd_responsible_listbox {p responsibles_list} {
+    global TkGnats Tksendpr Responsible
+    set Responsible ""
+
+    set alias [get_field_alias Responsible]
+    frame  $p.res -relief groove  -borderwidth 2
+    pack   $p.res -side top -expand true -fill both
+    button $p.res.lab -anchor w -text "${alias}: " -width 14 -command "helpMsg $alias" \
+            -relief flat -padx 0 -pady 0 -borderwidth 0
+    frame  $p.res.msg -relief flat
+    set wid [expr 2 + [get_max_strlen $responsibles_list]]
+    set ew  [entry  $p.res.msg.ent -width $wid -insertwidth 1 -insertofftime 400 \
+            -relief sunken -borderwidth 2 -background $TkGnats(EditFieldBackground) -highlightthickness 2 \
+            -textvariable Responsible]
+    lappend Tksendpr(tlist) $ew
+    trace variable Responsible w set_snd_responsible_ew
+    set_focus_style $ew
+    bind $ew <BackSpace> { tkEntrySetCursor %W [%W index insert] }
+    bind $ew <Control-h> { tkEntrySetCursor %W [%W index insert] }
+    set height [llength $responsibles_list]
+    if {$height > 6 } {
+        set height 6
+    }
+    scrollbar $p.res.msg.sb -command "$p.res.msg.list yview" -borderwidth 2 -relief sunken
+    listbox   $p.res.msg.list -yscroll "$p.res.msg.sb set" -setgrid 1 -relief sunken -borderwidth 2 \
+            -width $wid -height $height -exportselection false
+    eval   $p.res.msg.list insert end $responsibles_list
+    pack   $p.res.msg.ent  -side top   -fill x
+    pack   $p.res.msg.sb   -side right -fill y
+    pack   $p.res.msg.list -side right -fill both -expand true
+    pack   $p.res.lab      -side left  -anchor nw -ipady 4
+    pack   $p.res.msg      -side left  -anchor nw -fill y
+    bind   $p.res.msg.list <B1-ButtonRelease> "set_snd_responsible $p.res.msg.ent %W %y"
+    return $p.res.msg.list
 }
 
 proc set_snd_category_ew {a b c} {
     upvar #0 $a f
     global TkGnats
-    quickfill_entry_from_listbox f .eboxs.clb.cat.ent .eboxs.clb.cat.list $TkGnats(CategoryList)
+    quickfill_entry_from_listbox f .eboxs.clb.cat.msg.ent .eboxs.clb.cat.msg.list $TkGnats(CategoryList)
 }
  
-proc set_snd_submitter_ew {a b c} {
+proc set_snd_submitter-id_ew {a b c} {
     upvar #0 $a f
     global TkGnats
-    quickfill_entry_from_listbox f .eboxs.slb.sub.ent .eboxs.slb.sub.list $TkGnats(SubmitterList)
+    quickfill_entry_from_listbox f .eboxs.slb.sub.msg.ent .eboxs.slb.sub.msg.list $TkGnats(SubmitterList)
+}
+
+proc set_snd_responsible_ew {a b c} {
+    upvar #0 $a f
+    global TkGnats
+    quickfill_entry_from_listbox f .eboxs.rlb.res.msg.ent .eboxs.rlb.res.msg.list $TkGnats(ResponsibleList)
 }
 
 proc set_snd_category {ent w y} {
@@ -332,13 +362,22 @@ proc set_snd_category {ent w y} {
     trace variable Category w set_snd_category_ew
 }
 
-proc set_snd_submitter {ent w y} {
-    global Submitter
-    trace vdelete Submitter w set_snd_submitter_ew
+proc set_snd_submitter-id {ent w y} {
+    global Submitter-Id
+    trace vdelete Submitter-Id w set_snd_submitter-id_ew
     $ent delete 0 end
     set idx [$w nearest $y]
-    set Submitter [$w get $idx]
-    trace variable Submitter w set_snd_submitter_ew
+    set Submitter-Id [$w get $idx]
+    trace variable Submitter-Id w set_snd_submitter-id_ew
+}
+
+proc set_snd_responsible {ent w y} {
+    global Responsible
+    trace vdelete Responsible w set_snd_responsible_ew
+    $ent delete 0 end
+    set idx [$w nearest $y]
+    set Responsible [$w get $idx]
+    trace variable Responsible w set_snd_responsible_ew
 }
 
 proc env_fld_text {} {
@@ -378,9 +417,8 @@ if {"$TkGnats(LogName)" == "root"} {
 }
 
 # Set Create Defaults
-####foreach d { {Class sw-bug} {Priority medium} {Severity serious} {Confidential no} }
-foreach d [list [eval list Class $TkGnats(ClassesList)] {Priority medium} {Severity serious} \
-        {Confidential no}] {
+foreach d [list [eval list Class $TkGnats(ClassesList)] [eval list State $TkGnats(StatesList)] \
+        {Priority medium} {Severity serious} {Confidential no}] {
     if {![info exists TkGnats(CreateDefault[lindex $d 0])]} {
         set TkGnats(CreateDefault[lindex $d 0]) [lindex $d 1]
     }
@@ -389,23 +427,44 @@ foreach d [list [eval list Class $TkGnats(ClassesList)] {Priority medium} {Sever
 # List of entry widgets for traverse key binding
 set Tksendpr(tlist) {}
 
+set Tksendpr(radioflds) {
+    State
+    Confidential
+    Severity
+    Priority
+    Class
+}
+
+set Tksendpr(listboxflds) {
+    Category
+    Submitter-Id
+    Responsible
+}
+
 set Tksendpr(singletextflds) {
     Originator
+    X-GNATS-Notify
     Release
     Synopsis
-    Reply-To
 }
 
 if {$TkGnats(ReleaseBased)} {
     lappend Tksendpr(singletextflds) Keywords $TkGnats(Quarter) Date-Required
 }
+    
+set Tksendpr(multitextflds) {
+    >Description
+    >How-To-Repeat
+    >Environment
+    >Organization
+    >Fix
+    >Audit-Trail
+    >Unformatted
+    >Release-Note
+}
 
 #########
 
-# Since we don't use send-pr, set this to the TkGnats version
-#if {[catch {exec send-pr --version} Tksendpr(version)]} {
-#    set Tksendpr(version) unknown
-#}
 if {[regexp "tkgnats-\[^ \]*" $TkGnats(tkgnats_version) ver]} {
     set Tksendpr(version) $ver
 } {
@@ -424,6 +483,9 @@ menu       .mframe.file.m
 
 menubutton .mframe.edit -text "Edit" -menu .mframe.edit.m -underline 0
 menu       .mframe.edit.m
+.mframe.edit.m     configure -disabledforeground [.mframe.edit.m cget -foreground]
+.mframe.edit.m add command -label "Use right mouse button for Cut/Copy/Paste" -state disabled
+.mframe.edit.m add separator
 .mframe.edit.m add command -label "Fonts..." -command "edit_fonts"
 
 pack .mframe.file .mframe.edit -side left
@@ -433,6 +495,9 @@ menu       .mframe.help.m
 .mframe.help.m add command -label "Overview" \
         -command "helpMsg Create_Overview"
 .mframe.help.m add separator
+.mframe.help.m add command -label "Cut, Copy, Paste Operations" \
+        -command "helpMsg Cut_Copy_Paste"
+.mframe.help.m add separator
 .mframe.help.m add command -label "Field Definitions" \
         -command "helpMsg Field_Definitions"
 .mframe.help.m add separator
@@ -448,6 +513,8 @@ menu       .mframe.help.m
 .mframe.help.m add command -label "View Configuration Variables" \
         -command "helpMsg TkGnats_Variables"
 .mframe.help.m add separator
+.mframe.help.m add command -label "Changes" \
+        -command "helpMsg Changes"
 .mframe.help.m add command -label "About" \
         -command "helpMsg TkGnats_About"
 pack .mframe.help -side right
@@ -465,62 +532,74 @@ pack    .action.msg -side left -fill x -expand 1
 
 frame .eflds
 radiobar_frame .eflds .eflds.lb
-
-#####radiobar     .eflds.lb class        Class        {sw-bug doc-bug change-request support} None
-radiobar     .eflds.lb class        Class        $TkGnats(ClassesList) None
-radiobar     .eflds.lb priority     Priority     {low medium high} None
-radiobar     .eflds.lb severity     Severity     {non-critical serious critical} None
-radiobar     .eflds.lb confidential Confidential {no yes} None
-radiobar_set .eflds.lb class        $TkGnats(CreateDefaultClass)
-radiobar_set .eflds.lb priority     $TkGnats(CreateDefaultPriority)
-radiobar_set .eflds.lb severity     $TkGnats(CreateDefaultSeverity)
-radiobar_set .eflds.lb confidential $TkGnats(CreateDefaultConfidential)
+foreach {efield elist} [list Class $TkGnats(ClassesList) State $TkGnats(StatesList) Priority {low medium high} Severity {non-critical serious critical} Confidential {no yes}] {
+    if {![check_suppressed_field $efield]} {
+        radiobar     .eflds.lb [string tolower $efield] $efield $elist None
+        radiobar_set .eflds.lb [string tolower $efield] $TkGnats(CreateDefault$efield)
+    } {
+        set $efield [lindex $elist 0]
+    }
+}
 pack .eflds.lb -side left
 pack .eflds    -side top  -fill x -anchor w
 
 frame .eboxs
-frame .eboxs.clb
-snd_category_listbox  .eboxs.clb $TkGnats(CategoryList)
-frame .eboxs.slb
-snd_submitter_listbox .eboxs.slb $TkGnats(SubmitterList)
-pack .eboxs.clb .eboxs.slb -side top -anchor w -pady 2
-pack .eboxs -side top -fill x -anchor w -pady 2
-
-set Submitter $TkGnats(SUBMITTER)
-
-if {[info exists  TkGnats(CreateDefaultCategory)]} {
-    set Category $TkGnats(CreateDefaultCategory)
+set   nboxes 1
+array set xpad {1 0 2 20 3 0}
+foreach {efield eframe list} {Category clb Category Submitter-Id slb Submitter Responsible rlb Responsible} {
+    if {![check_suppressed_field $efield]} {
+        frame .eboxs.$eframe
+        snd_[string tolower $efield]_listbox .eboxs.$eframe $TkGnats(${list}List)
+        pack  .eboxs.$eframe -side left -anchor nw -pady 2 -fill y -padx $xpad($nboxes)
+        incr nboxes
+    } {
+        set $efield ""
+    }
+}
+if {$nboxes > 1} {
+    pack .eboxs -side top -fill x -anchor w -pady 2
 }
 
-lappend Tksendpr(tlist) [singletext . Originator 80 "$TkGnats(FullName)" 14]
-lappend Tksendpr(tlist) [singletext . Reply-To   80 "$TkGnats(EmailAddr)" 14]
-lappend Tksendpr(tlist) [singletext . Release    80 "" 14]
-lappend Tksendpr(tlist) [singletext . Synopsis   80 "" 14]
+set Submitter-Id $TkGnats(SUBMITTER)
 
-if {$TkGnats(ReleaseBased)} {
-    lappend Tksendpr(tlist) [singletext . Keywords          80 "" 14]
-    lappend Tksendpr(tlist) [singletext . $TkGnats(Quarter) 80 "" 14]
-    lappend Tksendpr(tlist) [singletext . Date-Required     40 "" 14]
+foreach f $Tksendpr(listboxflds) {
+    if {[info exists TkGnats(CreateDefault$f)]} {
+        set $f $TkGnats(CreateDefault$f)
+    }
 }
 
-set Tksendpr(multitextflds) {
-    >Description
-    >How-To-Repeat
-    >Environment
-    >Organization
-    >Fix
+foreach f $Tksendpr(singletextflds) {
+    if {[check_suppressed_field $f]} {
+        continue
+    }
+    if {[info exists TkGnats(CreateDefault$f)]} {
+        set     val $TkGnats(CreateDefault$f)
+    } {
+        if {$f == "Originator"} {
+            set val $TkGnats(FullName)
+        } {
+            set val ""
+        }
+    }
+    lappend Tksendpr(tlist) [singletext . $f 60 $val 14]
 }
 
-foreach tag $Tksendpr(multitextflds) {
-    set frm($tag) ""
+foreach f $Tksendpr(multitextflds) {
+    set frm($f) ""
 }
-
 set frm(>Environment)  [env_fld_text]
 set frm(>Organization) [org_fld_text]
+foreach f $Tksendpr(multitextflds) {
+    set field [string trimleft $f >]
+    if {[info exists TkGnats(CreateDefault$field)]} {
+        set frm($f) $TkGnats(CreateDefault$field)
+    }
+}
+
 set current_multi_text ""
 
 lappend Tksendpr(tlist) [make_txt_mb $Tksendpr(multitextflds)]
-switch_txt  ">Description" $Tksendpr(multitextflds)
+switch_txt $TkGnats(first_multitext) $Tksendpr(multitextflds)
 
 set_text_traversal $Tksendpr(tlist)
 
@@ -533,7 +612,6 @@ set_text_traversal $Tksendpr(tlist)
 #
 #pack .action -side top
 
-###wm title      . "TkGnats - Create Problem Report"
 wm title      . "TkGnats - [lindex $TkGnats(ServerInfo) 0] - $TkGnats(GNATS_ADDR)"
 wm iconbitmap . @$TkGnats(lib)/tksendpr.xbm
 wm iconname   . "$TkGnats(LogName)'s tksendpr"
