@@ -192,6 +192,14 @@ gnats (fp)
 	    localtime (&seconds));
   set_field (ARRIVAL_DATE, arrival_time);
 
+  if (check_state_type (field_value (STATE), "closed") && !field_value (CLOSED_DATE))
+    {
+      /* This PR has arrived with state=closed but no closed-date.
+         Set the last-modified and closed-date fields. */
+      set_field (LAST_MODIFIED, arrival_time);
+      set_field (CLOSED_DATE,   arrival_time);
+    }
+
   /* If the submitter isn't supposed to have a response time, don't bother
      trying to get it.  */
   if (submitter.rtime >= 0)
@@ -643,8 +651,15 @@ append_notify (person)
 
   notify[0] = '\0';
   notify_len = 0;
-
+  
   p = person;
+
+  end = (char *) strchr (p, '\n');
+  if (end != NULL)
+    {
+      *end = '\0';
+    }
+  
   while (p && *p != '\0')
     {
       while (*p == ' ') p++;
@@ -694,7 +709,7 @@ notify_responsible (responsible, subcontact, subnotify, cnotify,
 {
   FILE *msg;
   char *notify = (char *) alloca (BUFSIZ); /* FIXME - huge */
-  char *subc = NULL, *subn = NULL, *cnote = NULL;
+  char *subc = NULL, *subn = NULL, *cnote = NULL, *xnotify = NULL, *gnotify, *p;
   char buf[GNATS_TIME_LENGTH];
   Header_Name i;
 
@@ -719,6 +734,22 @@ notify_responsible (responsible, subcontact, subnotify, cnotify,
       xfree (cnote);
     }
 
+  gnotify = (char *) strdup (header_value (X_GNATS_NOTIFY));
+  xnotify = append_notify (gnotify);
+  if (xnotify)
+    {
+      strcat (notify, xnotify);
+      xfree (xnotify);
+    };
+  xfree (gnotify);
+
+  /* Strip away the trailing comma that was added by append_notify (). */
+  p = (char *) strrchr (xnotify, ',');
+  if (p != NULL)
+    {
+      *p = '\0';
+    }
+  
   block_signals ();
 
   msg = open_mail_file ();
