@@ -21,6 +21,13 @@ Software Foundation, 59 Temple Place - Suite 330, Boston, MA 02111, USA.  */
 #include "config.h"
 #include "gnats.h"
 #include "query.h"
+#include "db_conf.h"
+
+/* If 1, we're running the daemon.  */
+int is_daemon = 0;
+
+/* If 1, we're running a network client.  */
+int is_client = 1;
 
 /* The hostname and port of the GNATS server.  */
 char *host_name;
@@ -34,6 +41,10 @@ int debug = 0;
 
 struct option long_options[] =
 {
+  {"host", 1, NULL, 'H'},
+  {"user", 1, NULL, 'v'},
+  {"passwd", 1, NULL, 'w'},
+  {"directory", 1, NULL, 'd'},
   {"debug", 0, NULL, 'D'},
   {"help", 0, NULL, 'h'},
   {"version", 0, NULL, 'V'},
@@ -48,6 +59,7 @@ main (argc, argv)
      char **argv;
 {
   int optc;
+  char *user = "anonymous", *passwd = "guest";
 
   program_name = basename (argv[0]);
   if (argc == 1)
@@ -55,11 +67,27 @@ main (argc, argv)
 
   host_name = gnats_server;
 
-  while ((optc = getopt_long (argc, argv, "VDh",
+  while ((optc = getopt_long (argc, argv, "VDhd:H:v:w:",
 			      long_options, (int *) 0)) != EOF)
     {
       switch (optc)
 	{
+	case 'd':
+	  gnats_root = optarg;
+	  break;
+
+	case 'H':
+	  host_name = optarg;
+	  break;
+
+        case 'v':
+          user = optarg;
+          break;
+
+        case 'w':
+          passwd = optarg;
+          break;
+
 	case 'V':
 	  version ();
 	  exit (0);
@@ -80,7 +108,8 @@ main (argc, argv)
   if (! argv[optind])
     usage ();
 
-  client_init ();
+  client_init_gnats (user, passwd);
+
   if (debug)
     fprintf (stderr, "%s: writing `TYPE %s'\n", program_name,
 	     argv[optind]);
@@ -96,7 +125,11 @@ void
 usage (status)
      int status;
 {
-  fprintf (stderr, "Usage: %s [-V] submitter\n", program_name);
+  FILE *out = stderr;
+  fprintf (out, "\
+Usage: %s [--version] [--host=host] [-H host]\n\
+          [--directory=gnats_root] [-d gnats_root]\n\
+          [--user=userid] [--passwd=password] submitter\n", program_name);
   exit (status);
 }
 
